@@ -61,6 +61,7 @@ code from qwriter:
 
 
 QSettings *settings;
+QMenu *current_files_menu;
 
 
 void CDocument::update_status()
@@ -188,6 +189,8 @@ bool CDocument::save_with_name (const QString &fileName, const QString &codec)
   update_status();
 
   textEdit->document()->setModified (false);
+  
+  holder->update_current_files_menu();
 
   return true;
 }
@@ -336,6 +339,8 @@ CDocument* document_holder::create_new()
   doc->update_title();
   doc->update_status();
   
+  update_current_files_menu();
+  
   return doc;
 }
 
@@ -383,6 +388,8 @@ CDocument* document_holder::open_file (const QString &fileName, const QString &c
 
   tab_widget->setCurrentIndex (tab_widget->indexOf (doc->tab_page));
   
+  update_current_files_menu();
+  
   return doc;
 }
 
@@ -395,6 +402,8 @@ void document_holder::close_by_idx (int i)
   CDocument *d = list[i];
   list.removeAt (i);
   delete d;
+  
+  update_current_files_menu();
 }
 
 
@@ -424,6 +433,8 @@ bool CDocument::save_with_name_plain (const QString &fileName)
   out.setCodec (charset.toUtf8().data());
   out << textEdit->toPlainText();
 
+  holder->update_current_files_menu();
+  
   return true;
 }
 
@@ -457,13 +468,11 @@ QString CDocument::get_filename_at_cursor()
      
      QFileInfo inf (file_name);
      QDir cur_dir (inf.absolutePath());
-
          
      QString result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
      if (file_exists (result))
          return result;
 
-
      
      int i = x.lastIndexOf ("/");
      if (i < 0)
@@ -474,8 +483,7 @@ QString CDocument::get_filename_at_cursor()
 
      x = x.mid (i + 1);   
 
-     qDebug() << "x = " << x;
-
+//     qDebug() << "x = " << x;
      
      result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
      qDebug() << "in cur dir: " << result;
@@ -505,9 +513,6 @@ QString CDocument::get_filename_at_cursor()
 
       return cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
      }
-
- 
-  
 }
 
 
@@ -1378,7 +1383,6 @@ void CDocument::insert_image (const QString &full_path)
   textEdit->textCursor().insertText (get_insert_image (file_name, full_path, markup_mode));
 }
 
-
 void CTEAEdit::calc_auto_indent()
 {
   QTextCursor cur = textCursor();
@@ -1387,15 +1391,34 @@ void CTEAEdit::calc_auto_indent()
   
   QString s = cur.selectedText();
   int len = s.size();
-  for (int i = 0; i < len; i++)
-      if (! s.at(i).isSpace())
-         {
-          aindent = i; 
-          break;
-         }
+  
+  QChar t = ' '; //what to detect - space or tab?
+  if (s.indexOf ('\t') != -1)
+     t = '\t';
+  
+  if (t != '\t')
+     {
+      for (int i = 0; i < len; i++)
+          if (! s.at(i).isSpace())
+            {
+             aindent = i; 
+             break;
+            }
+     }
+  else   
+     {
+      for (int i = 0; i < len; i++)
+          if (s.at(i) != '\t')
+            {
+             aindent = i; 
+             break;
+            }
+     }
+           
 
   if (aindent != 0)
-     indent_val = indent_val.fill (' ', aindent);
+     //indent_val = indent_val.fill (' ', aindent);
+    indent_val = indent_val.fill (t, aindent);
   else 
       indent_val.clear();
 }
@@ -1798,6 +1821,57 @@ void CDocument::update_labels()
                                         settings->value ("label_end", "?]").toString());
 }
 
+//////////////////////////////////////////
+void document_holder::open_current()
+{
+  QAction *act = qobject_cast<QAction *>(sender());
+
+  QStringList current_files; 
+ 
+/* foreach (CDocument *d, list)
+         current_files.prepend (d->file_name);
+  
+  int i = current_files.indexOf (act->text());
+  if (i == -1)
+     return;
+*/
+ // open_file_triplex (current_files[i]);
+ 
+  CDocument *d = get_document_by_fname (act->text());
+  if (d)
+     {
+      tab_widget->setCurrentIndex (tab_widget->indexOf (d->tab_page));
+ //     return d;
+     }
+
+ 
+ 
+ 
+//  update_current_files_menu();
+}
+
+/*
+void document_holder::add_to_current_files (CDocument *d)
+{
+  
+  recent_files.prepend (d->file_name);
+  //if (recent_files.size() > 13)
+     //recent_files.removeLast();
+}
+*/
+
+void document_holder::update_current_files_menu()
+{
+ QStringList current_files; 
+ 
+ foreach (CDocument *d, list)
+         current_files.prepend (d->file_name);
+
+ 
+  current_files_menu->clear();
+  create_menu_from_list (this, current_files_menu, current_files, SLOT(open_current()));
+}
+
 
 
 /*
