@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2012 by Peter Semiletov                            *
+ *   Copyleft 2007-2014 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -251,7 +251,6 @@ public:
 
   
   document_holder *holder;
-//  CSyntaxHighlighter *highlighter;
   CSyntaxHighlighter *highlighter;
   
   
@@ -324,6 +323,9 @@ public:
   QStringList recent_files;
   QString recent_list_fname;
 
+  //QStringList current_files;
+
+  
   ~document_holder();
 
   CDocument* create_new();
@@ -345,11 +347,24 @@ public:
   void add_to_recent (CDocument *d);
   void update_recent_menu();
 
+  //void add_to_current_files (CDocument *d);
+  void update_current_files_menu();
+
+  
   CDocument* get_current();
 
-  public slots:
+public slots:
 
   void open_recent();
+  void open_current();
+  
+/*    
+public signals:
+  
+  void signal_file_open (const QString &fname);  
+  void signal_file_rename (const QString &oldname, const QString &newname);  
+  void signal_file_close (const QString &fname);  
+*/
 };
 
 
