@@ -244,6 +244,8 @@ public:
   QString dir_sessions;
   QString dir_hls;
 
+  QString dir_variants;
+
   QString dir_snippets;
   QString dir_scripts;
   QString dir_palettes;
@@ -328,7 +330,9 @@ main window callbacks
   void update_labels_menu();
   void update_labels_list();
 
+  void ed_variants();
 
+  
   void fm_full_info();
 
   void fm_hashsum_md5();
@@ -504,6 +508,9 @@ main window callbacks
   
   void remove_formatting();
 
+  void fn_variants_callback();
+
+  
 #ifdef SPELLCHECK_ENABLE
 
   void fn_change_spell_lang();
@@ -624,6 +631,9 @@ main window callbacks
   void set_eol_win();
   void set_eol_mac();
 
+  void fn_stat_words_lengths();
+
+  
   void guess_enc();
 
   void cal_add_days();
@@ -722,10 +732,13 @@ main window widgets
 
   QToolBar *fileToolBar;
   QToolBar *editToolBar;
+  QToolBar *filesToolBar;
 
   QAction *act_labels;
 
   QAction *act_test;
+  QAction *filesAct;
+  
   QAction *newAct;
   QAction *openAct;
   QAction *saveAct;
@@ -876,6 +889,7 @@ prefs window widgets
 
   void fman_items_select_by_regexp (bool mode);
 
+   
   void fman_find();
   void fman_find_next();
   void fman_find_prev();
