@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE" sourcelanguage="en">
+<TS version="2.1" language="de_DE" sourcelanguage="en">
 <context>
     <name>CAboutWindow</name>
     <message>
@@ -98,6 +98,13 @@ Do you want to save your changes?</source>
         <translation type="obsolete">Vorschau</translation>
     </message>
 </context>
+<context>
+    <name>CZORWindow</name>
+    <message>
+        <source> scaled to</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -1577,5 +1584,37 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>LaTeX: Straight to double angle quotes v2</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Words lengths</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> is unpacked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Word length: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Variants</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>variants</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>variants file %1 is not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
