@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr_FR" sourcelanguage="en">
+<TS version="2.1" language="fr_FR" sourcelanguage="en">
 <context>
     <name>CAboutWindow</name>
     <message>
@@ -103,6 +103,13 @@ Voulez-vous sauvegardez vos changements ?</translation>
         <translation type="obsolete">Presse-papier</translation>
     </message>
 </context>
+<context>
+    <name>CZORWindow</name>
+    <message>
+        <source> scaled to</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -1650,5 +1657,37 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>LaTeX: Straight to double angle quotes v2</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Words lengths</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> is unpacked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Word length: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Variants</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>variants</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>variants file %1 is not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
